Package: bvarnet
Title: Bayesian Estimation of Dynamic VAR Models using STAN
Version: 1.0.0
Authors@R: person("Florian", "Metwaly", , "f.j.metwaly@uva.nl", role = c("aut", "cre", "cph"), comment = c(ORCID = "0009-0001-8357-7870"))
Author: Florian Metwaly [aut, cre, cph] (ORCID:
    <https://orcid.org/0009-0001-8357-7870>)
Maintainer: Florian Metwaly <f.j.metwaly@uva.nl>
Description: Bayesian estimation of multilevel Vector Autoregression (VAR) models
    using Stan. Supports Gaussian, Binary, and Ordinal (adjacent category) outcome
    variables with random effects and customizable priors.
License: GPL (>= 3)
Encoding: UTF-8
URL: https://flo1met.github.io/bvarnet/,
        https://github.com/flo1met/bvarnet
BugReports: https://github.com/flo1met/bvarnet/issues
RoxygenNote: 7.3.3
Additional_repositories: https://mc-stan.org/r-packages/
Imports: instantiate, logspline, mvtnorm, posterior
Suggests: cmdstanr, bayesplot, knitr, qgraph, rmarkdown, testthat (>=
        3.0.0)
Config/testthat/edition: 3
Config/Needs/website: pkgdown
VignetteBuilder: knitr
Depends: R (>= 3.5)
LazyData: true
NeedsCompilation: yes
Packaged: 2026-05-19 10:29:47 UTC; florianmetwaly
Repository: CRAN
Date/Publication: 2026-05-27 09:00:02 UTC
