#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom instantiate stan_package_model
#' @importFrom stats complete.cases quantile rbinom rnorm runif sd setNames
## usethis namespace: end
NULL
