% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/set_priors.R
\name{format.bvarnet_prior}
\alias{format.bvarnet_prior}
\title{Format a bvarnet_prior for printing}
\usage{
\method{format}{bvarnet_prior}(x, half = FALSE, ...)
}
\arguments{
\item{x}{A \code{bvarnet_prior} object.}

\item{half}{Logical; if \code{TRUE} prepends "Half-" to indicate a
half-prior (used for positive-constrained parameters like sd_u and sigma).}

\item{...}{Ignored.}
}
\value{
A character string.
}
\description{
Format a bvarnet_prior for printing
}
